@@ -21,9 +21,9 @@
 #include <QAction>
 #include <QDateTime>
 
-#include <Plasma/PluginLoader>
+#include <Plasma5Support/PluginLoader>
 
-Q_DECLARE_METATYPE(Plasma::DataEngine::Data)
+Q_DECLARE_METATYPE(Plasma5Support::DataEngine::Data)
 
 #include "modelviewer.h"
 #include "serviceviewer.h"
@@ -62,12 +62,11 @@ EngineExplorer::EngineExplorer(QWidget *parent)
 
     setupUi(mainWidget);
 
-    m_engineManager = Plasma::PluginLoader::self();
     m_dataModel = new QStandardItemModel(this);
     const int size = m_title->style()->pixelMetric(QStyle::PM_LargeIconSize);
     m_title->setIconSize(QSize(size, size));
     m_title->setIcon(QIcon::fromTheme("plasma"));
-    connect(m_engines, SIGNAL(activated(QString)), this, SLOT(showEngine(QString)));
+    connect(m_engines, &QComboBox::textActivated, this, &EngineExplorer::showEngine);
     connect(m_sourceRequesterButton, SIGNAL(clicked(bool)), this, SLOT(requestSource()));
     connect(m_serviceRequesterButton, &QAbstractButton::clicked, this, &EngineExplorer::requestServiceForSource);
     m_data->setModel(m_dataModel);
@@ -96,9 +95,6 @@ EngineExplorer::~EngineExplorer()
 
 void EngineExplorer::cleanUp()
 {
-    if (!m_engineName.isEmpty()) {
-        // m_engineManager->unloadEngine(m_engineName);
-    }
 }
 
 void EngineExplorer::setApp(const QString &app)
@@ -133,7 +129,7 @@ void EngineExplorer::removeExtraRows(QStandardItem *parent, int preserve)
     }
 }
 
-void EngineExplorer::dataUpdated(const QString &source, const Plasma::DataEngine::Data &data)
+void EngineExplorer::dataUpdated(const QString &source, const Plasma5Support::DataEngine::Data &data)
 {
     QList<QStandardItem *> items = m_dataModel->findItems(source, Qt::MatchExactly);
 
@@ -150,7 +146,7 @@ void EngineExplorer::dataUpdated(const QString &source, const Plasma::DataEngine
 void EngineExplorer::listEngines()
 {
     m_engines->clear();
-    QVector<KPluginMetaData> engines = m_engineManager->listDataEngineMetaData(m_app);
+    QVector<KPluginMetaData> engines = Plasma5Support::PluginLoader::listDataEngineMetaData(m_app);
     std::sort(engines.begin(), engines.end(), [](auto lhs, auto rhs) {
         if (lhs.category() < rhs.category()) {
             return true;
@@ -161,7 +157,7 @@ void EngineExplorer::listEngines()
         return false;
     });
 
-    for (const KPluginMetaData &engine : qAsConst(engines)) {
+    for (const KPluginMetaData &engine : std::as_const(engines)) {
         m_engines->addItem(QIcon::fromTheme(engine.iconName()), engine.pluginId());
     }
 
@@ -183,17 +179,14 @@ void EngineExplorer::showEngine(const QString &name)
     m_engine = nullptr;
     m_sourceCount = 0;
 
-    if (!m_engineName.isEmpty()) {
-        // m_engineManager->unloadEngine(m_engineName);
-    }
-
     m_engineName = name;
     if (m_engineName.isEmpty()) {
         updateTitle();
         return;
     }
 
-    if (auto res = KPluginFactory::instantiatePlugin<Plasma::DataEngine>(KPluginMetaData::findPluginById(QStringLiteral("plasma/dataengine"), m_engineName))) {
+    if (auto res = KPluginFactory::instantiatePlugin<Plasma5Support::DataEngine>(
+            KPluginMetaData::findPluginById(QStringLiteral("plasma5support/dataengine"), m_engineName))) {
         m_engine = res.plugin;
     } else {
         m_engineName.clear();
@@ -203,8 +196,8 @@ void EngineExplorer::showEngine(const QString &name)
 
     // qDebug() << "showing engine " << m_engine->objectName();
     // qDebug() << "we have " << sources.count() << " data sources";
-    connect(m_engine, &Plasma::DataEngine::sourceAdded, this, &EngineExplorer::addSource);
-    connect(m_engine, &Plasma::DataEngine::sourceRemoved, this, &EngineExplorer::removeSource);
+    connect(m_engine, &Plasma5Support::DataEngine::sourceAdded, this, &EngineExplorer::addSource);
+    connect(m_engine, &Plasma5Support::DataEngine::sourceRemoved, this, &EngineExplorer::removeSource);
     const QStringList &sources = m_engine->sources();
     for (const QString &source : sources) {
         // qDebug() << "adding " << source;
@@ -314,7 +307,7 @@ void EngineExplorer::showDataContextMenu(const QPoint &point)
             viewer->show();
         } else if (activated == update) {
             m_engine->connectSource(source, this);
-            // Plasma::DataEngine::Data data = m_engine->query(source);
+            // Plasma5Support::DataEngine::Data data = m_engine->query(source);
         } else if (activated == remove) {
             removeSource(source);
         }
@@ -384,11 +377,6 @@ QString EngineExplorer::convertToString(const QVariant &value)
         QRectF rectF = value.toRectF();
         return QString("<x:%1, y:%2, w:%3, h:%4>").arg(rectF.x()).arg(rectF.y()).arg(rectF.width()).arg(rectF.height());
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    case QVariant::RegExp: {
-        return QString("%1").arg(value.toRegExp().pattern());
-    }
-#endif
     case QVariant::RegularExpression: {
         return value.toRegularExpression().pattern();
     }
@@ -424,7 +412,7 @@ QString EngineExplorer::convertToString(const QVariant &value)
             return QString("%1").arg(value.value<QDateTime>().toString());
         }
 
-        Plasma::DataEngine::Data data = value.value<Plasma::DataEngine::Data>();
+        Plasma5Support::DataEngine::Data data = value.value<Plasma5Support::DataEngine::Data>();
         if (!data.isEmpty()) {
             QStringList result;
 
@@ -447,7 +435,7 @@ QString EngineExplorer::convertToString(const QVariant &value)
     }
 }
 
-int EngineExplorer::showData(QStandardItem *parent, Plasma::DataEngine::Data data)
+int EngineExplorer::showData(QStandardItem *parent, Plasma5Support::DataEngine::Data data)
 {
     int rowCount = 0;
     for (auto it = data.constBegin(); it != data.constEnd(); it++) {
@@ -565,3 +553,5 @@ void EngineExplorer::enableButtons(bool enable)
         m_collapseButton->setEnabled(enable);
     }
 }
+
+#include "moc_engineexplorer.cpp"
